@@ -1,9 +1,9 @@
 #!/usr/bin/perl
 #
-my $revision = '$Id: Sanitizer.pm,v 1.89 2004/09/02 10:14:15 bre Exp $';
+my $revision = '$Id: Sanitizer.pm,v 1.90 2005/01/04 20:30:13 bre Exp $';
 my $version = 'Anomy 0.0.0 : Sanitizer.pm';
 #
-##  Copyright (c) 2000-2004 Bjarni R. Einarsson. All rights reserved.
+##  Copyright (c) 2000-2005 Bjarni R. Einarsson. All rights reserved.
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
 ##  the Free Software Foundation; either version 2 of the License, or
@@ -51,7 +51,7 @@ use bytes;
 BEGIN {
     use Exporter  ();
     use vars      qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION      = do { my @r = (q$Revision: 1.89 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION      = do { my @r = (q$Revision: 1.90 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
     @ISA          = qw(Exporter);
     @EXPORT       = qw( );
     @EXPORT_OK    = qw( );
@@ -1074,6 +1074,16 @@ sub CreateAttFile
     }
     while (($cnt++ < 5) && (!defined $fh));
 
+    # FIXME: This is better than the old cryptic error, but we really 
+    #        should just return undef and let the caller handle things.
+    # Unfortunately, when I tested that it caused unpredictable cleanup
+    # behavior if file-name templates were non-unique.
+    # 
+    die "Failed to create $$fn: $!\n".
+        "HINT: Make sure file_name_tpl suggests file names in a directory\n".
+        "      which exists and is writable by the Sanitizer.\n" 
+      unless (defined ($fh));
+
     binmode($fh);
     return $fh;
 }
